/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DefaultArchiveHelper.java 2950 2008-04-25 09:14:23Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api;

import java.net.URL;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchive;


/**
 * the default archive helper, all classes can be accessed with a classloader on root
 * directory of the archive. Path of classes URL must end with .class.
 * @author Gael Lalire
 */
public class DefaultArchiveHelper implements IArchiveHelper {

    /**
     * The archive.
     */
    private IArchive archive;

    /**
     * Constructor.
     * @param archive the archive.
     */
    public DefaultArchiveHelper(final IArchive archive) {
        this.archive = archive;
    }

    /**
     * @param className the class name
     * @return the URL of the class named className
     * @throws ArchiveException if error occurs on archive
     */
    public URL getClassURL(final String className) throws ArchiveException {
        return archive.getResource(className.replace('.', '/').concat(".class"));
    }

    /**
     * @return the URL list of the all classes in archive
     * @throws ArchiveException if error occurs on archive
     */
    public List<URL> listClassURL() throws ArchiveException {
        List<URL> classURLList = new ArrayList<URL>();
        Iterator<URL> iterator = archive.getResources();
        while (iterator.hasNext()) {
            URL url = iterator.next();
            // only .class
            String className = url.getPath().toLowerCase();
            if (className.endsWith(".class")) {
                classURLList.add(url);
            }
        }
        return classURLList;
    }

    /**
     * @return the archive
     */
    public IArchive getArchive() {
        return archive;
    }

}
