/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FieldMetadataConfigurator.java 2950 2008-04-25 09:14:23Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.configurator.metadata;

import org.ow2.util.scan.api.configurator.BasicConfigurator;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.metadata.IClassMetadata;
import org.ow2.util.scan.api.metadata.IFieldMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;

/**
 * FieldMetadataConfigurator is a configurator of field specific to FieldMetata.
 * @author Gael Lalire
 * @param <C> class of ClassMetadata
 * @param <M> class of MethodMetadata
 * @param <F> class of FieldMetadata
 */
public abstract class FieldMetadataConfigurator<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>>
        extends BasicConfigurator implements IFieldConfigurator {

    /**
     * the field metadata.
     */
    private F fieldMetadata;

    /**
     * @return the field metadata
     */
    protected F getFieldMetadata() {
        return fieldMetadata;
    }

    /**
     * Construtor.
     * @param fieldMetadata the field metadata
     */
    public FieldMetadataConfigurator(final F fieldMetadata) {
        this.fieldMetadata = fieldMetadata;
    }

    /**
     * Add the field metadata to his class metadata when configueration ended.
     */
    @Override
    public void configurationComplete() {
        fieldMetadata.getClassMetadata().addFieldMetadata(fieldMetadata);
    }

}
